pub struct CardDto {Show 44 fields
pub id: String,
pub identity: CardIdentity,
pub color: String,
pub mana_cost: String,
pub cmc: i32,
pub types: Vec<String>,
pub subtypes: Vec<String>,
pub supertypes: Vec<String>,
pub power: Option<String>,
pub toughness: Option<String>,
pub base_power: Option<i32>,
pub base_toughness: Option<i32>,
pub text: String,
pub controller_id: String,
pub owner_id: String,
pub tapped: bool,
pub is_crewed: bool,
pub is_attacking: bool,
pub attacking_player_id: Option<String>,
pub attack_target_id: Option<String>,
pub keywords: Vec<String>,
pub counters: BTreeMap<String, u32>,
pub damage: i32,
pub summoning_sick: bool,
pub is_copy: bool,
pub is_double_faced: bool,
pub is_transformed: bool,
pub is_face_down: bool,
pub is_bestowed: bool,
pub phased_out: bool,
pub exerted: bool,
pub is_ring_bearer: bool,
pub attached_to: Option<String>,
pub attachment_ids: Vec<String>,
pub merged_card_ids: Vec<String>,
pub flashback_cost: Option<String>,
pub kicker_cost: Option<String>,
pub effective_mana_cost: Option<String>,
pub madness_cost: Option<String>,
pub is_madness_exiled: bool,
pub is_plotted: bool,
pub is_warp_exiled: bool,
pub foil: bool,
pub would_die_in_combat: bool,
}Fields
id: Stringidentity: CardIdentitycolor: Stringmana_cost: Stringcmc: i32types: Vec<String>subtypes: Vec<String>supertypes: Vec<String>power: Option<String>toughness: Option<String>base_power: Option<i32>base_toughness: Option<i32>text: Stringcontroller_id: Stringowner_id: Stringtapped: boolis_crewed: boolis_attacking: boolattacking_player_id: Option<String>attack_target_id: Option<String>keywords: Vec<String>counters: BTreeMap<String, u32>damage: i32summoning_sick: boolis_copy: boolis_double_faced: boolis_transformed: boolis_face_down: boolis_bestowed: boolphased_out: boolexerted: boolis_ring_bearer: boolattached_to: Option<String>attachment_ids: Vec<String>merged_card_ids: Vec<String>flashback_cost: Option<String>kicker_cost: Option<String>effective_mana_cost: Option<String>madness_cost: Option<String>is_madness_exiled: boolis_plotted: boolis_warp_exiled: boolfoil: boolwould_die_in_combat: boolTrait Implementations
Sourceimpl<'de> Deserialize<'de> for CardDto
impl<'de> Deserialize<'de> for CardDto
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl TS for CardDto
impl TS for CardDto
Sourcetype WithoutGenerics = CardDto
type WithoutGenerics = CardDto
If this type does not have generic parameters, then
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or ().
The only requirement for these dummy types is that EXPORT_TO must be None. Read moreSourcefn decl_concrete() -> String
fn decl_concrete() -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl() -> String
fn decl() -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline() -> String
fn inline() -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened() -> String
fn inline_flattened() -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<&'static Path>
fn output_path() -> Option<&'static Path>
Returns the output path to where
The returned path does not include the base directory from
T should be exported.The returned path does not include the base directory from
TS_RS_EXPORT_DIR. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all dependency of this type.
Sourceconst DOCS: Option<&'static str> = None
const DOCS: Option<&'static str> = None
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn dependencies() -> Vec<Dependency>where
Self: 'static,
fn dependencies() -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export() -> Result<(), ExportError>where
Self: 'static,
fn export() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all() -> Result<(), ExportError>where
Self: 'static,
fn export_all() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
fn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
Manually export this type into the given directory, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string() -> Result<String, ExportError>where
Self: 'static,
fn export_to_string() -> Result<String, ExportError>where
Self: 'static,