AlternativeCostKind

Enum AlternativeCostKind 

pub enum AlternativeCostKind {
Show 30 variants Flashback, Spectacle, Evoke, Dash, Blitz, Escape, Overload, Madness, Foretell, Emerge, Suspend, Morph, Megamorph, Bestow, Warp, SacrificeAlt, Plot, Awaken, Disturb, Harmonize, Freerunning, Impending, Mayhem, MTMtE, Mutate, Prowl, Sneak, Surge, WebSlinging, Plotted,
}
Mirrors the engine’s AlternativeCost (itself a mirror of Java’s).

Variants



Flashback



Spectacle



Evoke



Dash



Blitz



Escape



Overload



Madness



Foretell



Emerge



Suspend



Morph



Megamorph



Bestow



Warp



SacrificeAlt



Plot



Awaken



Disturb



Harmonize



Freerunning



Impending



Mayhem



MTMtE



Mutate



Prowl



Sneak



Surge



WebSlinging



Plotted